==> haskell-structured-0.1.1-311.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-4UoJHQsdR4aGobtqIk54Cs
key:                  structured-0.1.1-4UoJHQsdR4aGobtqIk54Cs
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  3483a0212abe4eec2f176aecd87abc3b
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-4UoJHQsdR4aGobtqIk54Cs
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.1-312-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-EsM7jkXFpbP7Tj598joaMX
key:                  structured-0.1.1-EsM7jkXFpbP7Tj598joaMX
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  1959c1ee1a85317ab160fcd3f417aa6d
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-EsM7jkXFpbP7Tj598joaMX
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y array-0.5.6.0 base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
